@@ -25,7 +25,7 @@ def get_existent_path(*paths):
 if sys.platform == "win32":
     USERPROFILE_ANIMDL_PATH = os.getenv("userprofile", ".") + "/.animdl/config.yml"
 else:
-    USERPROFILE_ANIMDL_PATH = os.getenv("HOME", ".") + "/animdl/config.yml"
+    USERPROFILE_ANIMDL_PATH = os.getenv("HOME", ".") + "/.config/animdl/config.yml"
 
 CONFIGURATION_FILE_PATH = get_existent_path(
     os.getenv("ANIMDL_CONFIG", "./animdl_config.yml"),
@@ -50,6 +50,7 @@ DEFAULT_CONFIG = {
         "gogoanime": "https://gogoanime.cm/",
         "haho": "https://haho.moe/",
         "hentaistream": "https://hentaistream.moe/",
+        "kamyroll_api": "https://api.kamyroll.tech/",
         "tenshi": "https://tenshi.moe/",
         "nyaasi": "https://nyaa.si/",
         "twist": "https://twist.moe/",
@@ -67,7 +68,7 @@ DEFAULT_CONFIG = {
             "opts": [],
         },
         "iina": {
-            "executable": "iina-cli",
+            "executable": "iina",
             "opts": [],
         },
         "celluloid": {
@@ -83,13 +84,6 @@ DEFAULT_CONFIG = {
             "opts": [],
         },
     },
-    "qbittorrent": {
-        "endpoint_url": "http://127.0.0.1:8080",
-        "credentials": {
-            "username": "admin",
-            "password": "youshallnotpass",
-        },
-    },
     "schedule": {
         "site_url": "https://graphql.anilist.co/",
         "date_format": "%b. %d, %A",
@@ -128,6 +122,7 @@ ANIMIXPLAY = SITE_URLS.get("animixplay")
 ANIMTIME = SITE_URLS.get("animtime")
 CRUNCHYROLL = SITE_URLS.get("crunchyroll")
 KAWAIIFU = SITE_URLS.get("kawaiifu")
+KAMYROLL_API = SITE_URLS.get("kamyroll_api")
 GOGOANIME = SITE_URLS.get("gogoanime")
 NYAASI = SITE_URLS.get("nyaasi")
 TENSHI = SITE_URLS.get("tenshi")
@@ -156,11 +151,6 @@ FFMPEG_EXECUTABLE = FFMPEG_SETTINGS.get("executable", "ffmpeg")
 FFMPEG_HLS = FFMPEG_SETTINGS.get("hls_download", False)
 FFMPEG_SUBMERGE = FFMPEG_SETTINGS.get("submerge", True)
 
-QBITTORENT_CONFIG = CONFIG.get("qbittorrent", {})
-
-QBITTORENT_ENDPOINT = QBITTORENT_CONFIG.get("endpoint_url")
-QBITTORENT_CREDENTIALS = QBITTORENT_CONFIG.get("credentials", {})
-
 DISCORD_PRESENCE = CONFIG.get("discord_presence", False)
 
 FZF = CONFIG.get("fzf", {})
